@@ -183,9 +183,9 @@ class PhaseSpaceFactor(UnevaluatedExpression):
         return sp.sqrt(q_squared) / denominator
 
     def _latex(self, printer: LatexPrinter, *args: Any) -> str:
-        s, m_a, _ = self.args
+        s, *_ = self.args
         s = printer._print(s)
-        subscript = _indices_to_subscript(_determine_indices(m_a))
+        subscript = _indices_to_subscript(_determine_indices(s))
         name = R"\rho" + subscript if self._name is None else self._name
         return fR"{name}\left({s}\right)"
 
@@ -218,9 +218,9 @@ class PhaseSpaceFactorAbs(UnevaluatedExpression):
         return sp.sqrt(sp.Abs(q_squared)) / denominator
 
     def _latex(self, printer: LatexPrinter, *args: Any) -> str:
-        s, m_a, _ = self.args
+        s, *_ = self.args
         s = printer._print(s)
-        subscript = _indices_to_subscript(_determine_indices(m_a))
+        subscript = _indices_to_subscript(_determine_indices(s))
         name = R"\hat{\rho}" + subscript if self._name is None else self._name
         return fR"{name}\left({s}\right)"
 
@@ -250,9 +250,9 @@ class PhaseSpaceFactorAnalytic(UnevaluatedExpression):
         return _analytic_continuation(rho_hat, s, s_threshold)
 
     def _latex(self, printer: LatexPrinter, *args: Any) -> str:
-        s, m_a, _ = self.args
+        s, *_ = self.args
         s = printer._print(s)
-        subscript = _indices_to_subscript(_determine_indices(m_a))
+        subscript = _indices_to_subscript(_determine_indices(s))
         name = (
             R"\rho^\mathrm{ac}" + subscript
             if self._name is None
@@ -283,9 +283,9 @@ class PhaseSpaceFactorComplex(UnevaluatedExpression):
         return ComplexSqrt(q_squared) / denominator
 
     def _latex(self, printer: LatexPrinter, *args: Any) -> str:
-        s, m_a, _ = self.args
+        s, *_ = self.args
         s = printer._print(s)
-        subscript = _indices_to_subscript(_determine_indices(m_a))
+        subscript = _indices_to_subscript(_determine_indices(s))
         name = (
             R"\rho^\mathrm{c}" + subscript
             if self._name is None
@@ -348,6 +348,7 @@ class CoupledWidth(UnevaluatedExpression):
         angular_momentum: sp.Symbol,
         meson_radius: sp.Symbol,
         phsp_factor: Optional[PhaseSpaceFactorProtocol] = None,
+        name: Optional[str] = None,
         evaluate: bool = False,
     ) -> "CoupledWidth":
         args = sp.sympify(
@@ -361,8 +362,8 @@ class CoupledWidth(UnevaluatedExpression):
         expr._assumptions = cls.default_assumptions
         expr._mhash = None
         expr._args = args
-        expr._name = None
-        expr.phsp_factor = PhaseSpaceFactor
+        expr._name = name
+        expr.phsp_factor = phsp_factor
         if evaluate:
             return expr.evaluate()
         return expr
@@ -370,7 +371,7 @@ class CoupledWidth(UnevaluatedExpression):
     def __getnewargs__(self) -> tuple:
         # Pickling support, see
         # https://github.com/sympy/sympy/blob/1.8/sympy/core/basic.py#L124-L126
-        return (*self.args, self._name, self.phsp_factor)
+        return (*self.args, self.phsp_factor, self._name)
 
     def evaluate(self) -> sp.Expr:
         s, mass0, gamma0, m_a, m_b, angular_momentum, meson_radius = self.args
@@ -411,7 +412,8 @@ class BreakupMomentumSquared(UnevaluatedExpression):
         m_b: Mass of decay product :math:`b`.
 
     It's up to the caller in which way to take the square root of this break-up
-    momentum.See :doc:`usage/analytic-continuation` and `.ComplexSqrt`.
+    momentum.See :doc:`/usage/dynamics/analytic-continuation` and
+    `.ComplexSqrt`.
     """
 
     is_commutative = True
@@ -426,9 +428,9 @@ class BreakupMomentumSquared(UnevaluatedExpression):
         return (s - (m_a + m_b) ** 2) * (s - (m_a - m_b) ** 2) / (4 * s)
 
     def _latex(self, printer: LatexPrinter, *args: Any) -> str:
-        s, m_a, _ = self.args
+        s, *_ = self.args
         s = printer._print(s)
-        subscript = _indices_to_subscript(_determine_indices(m_a))
+        subscript = _indices_to_subscript(_determine_indices(s))
         name = "q^2" + subscript if self._name is None else self._name
         return fR"{name}\left({s}\right)"
 
@@ -456,10 +458,6 @@ def relativistic_breit_wigner_with_ff(  # pylint: disable=too-many-arguments
 ) -> sp.Expr:
     """Relativistic Breit-Wigner with `.BlattWeisskopfSquared` factor.
 
-    Note that this lineshape is set to zero for :math:`s < (m_a + m_b)^2` as a
-    continuation of the `.BlattWeisskopfSquared` damping factor behavior at
-    :math:`s = (m_a + m_b)^2`.
-
     See :ref:`usage/dynamics:_With_ form factor` and
     :pdg-review:`2020; Resonances; p.6`.
     """
